@@ -12,9 +12,11 @@ from equihash import solve
 try:
   from pwdsphinx import bin2pass, sphinxlib
   from pwdsphinx.config import getcfg
+  from pwdsphinx.consts import *
 except ImportError:
   import bin2pass, sphinxlib
   from config import getcfg
+  from consts import *
 
 win=False
 if platform.system() == 'Windows':
@@ -49,27 +51,12 @@ if verbose:
 
 #### consts ####
 
-CREATE   =b'\x00' # sphinx
-READ     =b'\x33' # blob
-UNDO     =b'\x55' # change sphinx
-GET      =b'\x66' # sphinx
-COMMIT   =b'\x99' # change sphinx
-CHANGE   =b'\xaa' # sphinx
-DELETE   =b'\xff' # sphinx+blobs
-
-CHALLENGE_CREATE = b'\x5a'
-CHALLENGE_VERIFY = b'\xa5'
-
 ENC_CTX = b"sphinx encryption key"
 SIGN_CTX = b"sphinx signing key"
 SALT_CTX = b"sphinx host salt"
 PASS_CTX = b"sphinx password context"
 CHECK_CTX = b"sphinx check digit context"
 
-VERSION = b'\x00'
-
-RULE_SIZE = 79
-
 #### Helper fns ####
 
 def get_masterkey():
@@ -194,7 +181,7 @@ def commit_undo(s, op, pwd, user, host):
   r, alpha = sphinxlib.challenge(pwd)
   msg = b''.join([op, id, alpha])
   s = ratelimit(s, msg)
-  if not auth(s,id,pwd,r):
+  if not auth(s,id,alpha,pwd,r):
     s.close()
     raise ValueError("Failed to authenticate to server while %s" % "committing" if op == COMMIT else "undoing")
   if s.recv(2)!=b'ok':
@@ -256,7 +243,7 @@ def update_rec(s, host, item): # this is only for user blobs. a UI feature offer
       blob = sign_blob(blob, id, b'')
     s.send(blob)
 
-def auth(s,id,pwd=None,r=None):
+def auth(s,id,alpha=None,pwd=None,r=None):
   if r is None:
     nonce = s.recv(32)
     if len(nonce)!=32:
@@ -268,7 +255,7 @@ def auth(s,id,pwd=None,r=None):
        return False
     beta = msg[:32]
     nonce = msg[32:]
-    rwd = sphinxlib.finish(pwd, r, beta, id)
+    rwd = sphinxlib.finish(pwd, r, alpha, beta, id)
 
   sk, pk = get_signkey(id, rwd)
   sig = pysodium.crypto_sign_detached(nonce,sk)
@@ -356,7 +343,7 @@ def create(s, pwd, user, host, char_classes='uld', symbols=bin2pass.symbols, siz
     # or (less probable) the initial message was longer/shorter than the 65 bytes we sent
     # or (even? less probable) the value alpha received by the server is not a valid point
     # both of these less probable causes point at corruption during transport
-  rwd = sphinxlib.finish(pwd, r, beta, id)
+  rwd = sphinxlib.finish(pwd, r, alpha, beta, id)
 
   # second phase, derive new auth signing pubkey
   sk, pk = get_signkey(id, rwd)
@@ -405,7 +392,7 @@ def get(s, pwd, user, host):
       raise ValueError("ERROR: Either the record does not exist, or the request to server was corrupted during transport.")
   beta = resp[:32]
   rules = resp[32:]
-  rwd = sphinxlib.finish(pwd, r, beta, id)
+  rwd = sphinxlib.finish(pwd, r, alpha, beta, id)
 
   try:
     classes, symbols, size, checkdigit, xormask = unpack_rule(rules)
@@ -450,7 +437,7 @@ def change(s, oldpwd, newpwd, user, host, classes='uld', symbols=bin2pass.symbol
   msg = b''.join([CHANGE, id, alpha])
   s = ratelimit(s, msg)
   # auth: do sphinx with current seed, use it to sign the nonce
-  if not auth(s,id,oldpwd,r):
+  if not auth(s,id,alpha,oldpwd,r):
     s.close()
     raise ValueError("ERROR: Failed to authenticate using old password to server while changing password on server or record doesn't exist")
 
@@ -460,7 +447,7 @@ def change(s, oldpwd, newpwd, user, host, classes='uld', symbols=bin2pass.symbol
   if beta == b'\x00\x04fail' or len(beta)!=32:
     s.close()
     raise ValueError("ERROR: changing password failed due to corruption during transport.")
-  rwd = sphinxlib.finish(newpwd, r, beta, id)
+  rwd = sphinxlib.finish(newpwd, r, alpha, beta, id)
 
   if validate_password:
       checkdigit = pysodium.crypto_generichash(CHECK_CTX, rwd, 1)[0]
@@ -504,7 +491,7 @@ def delete(s, pwd, user, host):
   r, alpha = sphinxlib.challenge(pwd)
   msg = b''.join([DELETE, id, alpha])
   s = ratelimit(s, msg)
-  rwd = auth(s,id,pwd,r)
+  rwd = auth(s,id,alpha,pwd,r)
   if not rwd:
     s.close()
     raise ValueError("ERROR: Failed to authenticate to server while deleting password on server or record doesn't exist")
@@ -526,7 +513,7 @@ def delete(s, pwd, user, host):
   blob = s.recv(bsize)
   if blob == b'fail':
     s.close()
-    raise ValueError("ERROR: invalid signature on list of users", file=sys.stderr)
+    raise ValueError("ERROR: invalid signature on list of users")
   version, blob = decrypt_blob(blob)
   users = set(blob.decode().split('\x00'))
   if user not in users:
